
// From L. Christiano home page, 
//http://faculty.wcas.northwestern.edu/~lchrist/course/Oslo_2014/syllabus.htm

var kbar, i, c, R, omegabar, Rk, n, sigma, spread, credit, bankrupt, GDP, wedge, A,g;

varexo sigma_e eA eg;

parameters sigma_ss mmu gamma alpha delta beta rhosigma gam rhoA sigmaA rhog sigmag gss;

%dbstop in bgg_rbc_steadystate at 10
sigma_ss=0.26;
mmu=0.21;
gamma=0.97;
alpha=1/3;
delta=0.02;
beta=1.03^(-.25);
rhosigma=0.97;
gam=1;
gss = .6;

rhoA=0.95;
sigmaA = 0.007;

rhog=0.95;
sigmag = 0.007;

model;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Auxiliary expressions.  These simplify the equations without adding
% additional variables.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
/*
Inside the model block, Dynare allows the creation of model-local variables, 
which constitute a simple way to share a common expression between several equations. 
The syntax consists of a pound sign (#) followed by the name of the new model local variable 
(which must not be declared as in Variable declarations), an equal sign, 
and the expression for which this new variable will stand. 
Later on, every time this variable appears in the model, Dynare will substitute it 
by the expression assigned to the variable. 
Note that the scope of this variable is restricted to the model block; 
it cannot be used outside. A model local variable declaration looks like:
# VARIABLE_NAME = MODEL_EXPRESSION;
*/

  # F          = (normcdf(((log(omegabar) + sigma(-1)^2 / 2) / sigma(-1))));
  # G          = (normcdf((log(omegabar) + sigma(-1)^2 / 2) / sigma(-1) - sigma(-1)));
  # d          =  mmu * G  * (1 + Rk) * kbar(-1);
  # Fp1        = (normcdf((log(omegabar(+1)) + sigma^2 / 2) / sigma));
  # Gp1        = (normcdf((log(omegabar(+1)) + sigma^2 / 2) / sigma - sigma));
  # GAMMA      = omegabar*(1-F)+G;
  # GAMMAp1    = omegabar(+1)*(1-Fp1)+Gp1;
  # dFp1       = normpdf((log(omegabar(+1)) + sigma^2 / 2) / sigma) / (omegabar(+1) * sigma);
  
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Equilibrium equations.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
  % 1. resource constraint
    A*kbar(-1)^alpha = c + i + d + g ;
  
  % 2. Law of motion for capital
    kbar = (1 - delta) * kbar(-1) + i;
  
  % 3. Household FOC w.r.t. risk-free bonds
    1 = beta * (c(+1)/c)^(-gam)*(1+R);
  
  % efficiency condition associated with the contract
    (1-Fp1)/(1-GAMMAp1)-((1 + Rk(+1)) / (1 + R))*(1-Fp1-mmu*omegabar(+1)*dFp1)/(1-((1 + Rk(+1)) / (1 + R))*(GAMMAp1-mmu*Gp1));
  
  % Definition of return of entrepreneurs, Rk
    1 + Rk = A*alpha*kbar(-1)^(alpha-1)  + 1 - delta;
    
  % Zero profit condition
    kbar(-1)*(1 - ((1+Rk)/(1+R(-1)))*(GAMMA-mmu*G)) - n(-1);
  
  % Law of motion of net worth
    n = gamma*(1-GAMMA)*(1+Rk)*kbar(-1);

  % borrowing:
    credit = kbar-n;

  % interest rate spread
    spread = ((1+Rk)/(1+R(-1)))*(kbar(-1)/credit(-1))*omegabar;

   % Shock 
   log(sigma / sigma_ss) = rhosigma * log(sigma(-1) / sigma_ss)  + sigma_e ;
   log(A) = rhoA*log(A(-1)) + eA;
   log(g/gss) = rhog*log(g(-1)/gss) + eg; 

   GDP = c + i + g;

   wedge = (1-(1+R)/(1+Rk(+1)));

   bankrupt = F;
end;

/*
shocks;
var sigma_e; 
stderr .1;
end;
*/


shocks;
var eA; 
//stderr sigA;
stderr .1;
end;

/*
shocks;
var eg; 
//stderr sigA;
stderr .1;
end;
*/

steady;

check;
//stoch_simul(order=1,irf=20) kbar, i, c, R, omegabar, Rk, sigma, spread, credit, bankrupt,GDP,wedge;
stoch_simul(order=1,irf=40);